@@ -25,6 +25,7 @@
 #include <glib/gi18n.h>
 
 #include <nm-setting-connection.h>
+#include <nm-utils.h>
 
 #include "page-master.h"
 #include "nm-connection-editor.h"
@@ -368,7 +369,7 @@ add_connection (NMConnection *connection,
 	iface_name = gtk_entry_get_text (priv->interface_name);
 	if (!*iface_name)
 		iface_name = nm_connection_get_virtual_iface_name (connection);
-	if (!*iface_name)
+	if (!iface_name || !nm_utils_iface_valid_name (iface_name))
 		iface_name = nm_connection_get_id (connection);
 	name = g_strdup_printf (_("%s slave %d"), iface_name,
 	                        gtk_tree_model_iter_n_children (priv->connections_model, NULL) + 1);
